@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 120.system.php 1543 2010-12-07 11:08:41Z d00p $
+ * @version    $Id$
  */
 
 return array(
@@ -113,6 +113,35 @@ return array(
 					'type' => 'hidden',
 					'default' => 'www-data',
 					),
+				'system_report_enable' => array(
+					'label' => $lng['serversettings']['report']['report'],
+					'settinggroup' => 'system',
+					'varname' => 'report_enable',
+					'type' => 'bool',
+					'default' => true,
+					'cronmodule' => 'froxlor/reports',
+					'save_method' => 'storeSettingField',
+					),
+				'system_report_webmax' => array(
+					'label' => $lng['serversettings']['report']['webmax'],
+					'settinggroup' => 'system',
+					'varname' => 'report_webmax',
+					'type' => 'int',
+					'int_min' => 1,
+					'int_max' => 99,
+					'default' => 90,
+					'save_method' => 'storeSettingField',
+					),
+				'system_report_trafficmax' => array(
+					'label' => $lng['serversettings']['report']['trafficmax'],
+					'settinggroup' => 'system',
+					'varname' => 'report_trafficmax',
+					'type' => 'int',
+					'int_min' => 1,
+					'int_max' => 99,
+					'default' => 90,
+					'save_method' => 'storeSettingField',
+					),
 				'system_debug_cron' => array(
 					'label' => $lng['serversettings']['cron']['debug'],
 					'settinggroup' => 'system',
