@@ -97,11 +97,8 @@ elseif($page == 'accounts')
 			   && $_POST['send'] == 'send')
 			{
 				$db->query("UPDATE `" . TABLE_FTP_USERS . "` SET `up_count`=`up_count`+'" . (int)$result['up_count'] . "', `up_bytes`=`up_bytes`+'" . (int)$result['up_bytes'] . "', `down_count`=`down_count`+'" . (int)$result['down_count'] . "', `down_bytes`=`down_bytes`+'" . (int)$result['down_bytes'] . "' WHERE `username`='" . $db->escape($userinfo['loginname']) . "'");
-				$result = $db->query("SELECT `username` FROM `" . TABLE_FTP_USERS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `id`='" . (int)$id . "'");
-				while($row = $db->fetch_array($result))
-				{
-					$db->query("DELETE FROM `" . TABLE_FTP_QUOTATALLIES . "` WHERE `name` = '" . $db->escape($row['username']) . "'");
-				}
+				$result = $db->query_first("SELECT `username`, `homedir` FROM `" . TABLE_FTP_USERS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `id`='" . (int)$id . "'");
+				$db->query("DELETE FROM `" . TABLE_FTP_QUOTATALLIES . "` WHERE `name` = '" . $db->escape($result['username']) . "'");
 				$db->query("DELETE FROM `" . TABLE_FTP_USERS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `id`='" . (int)$id . "'");
 				$log->logAction(USR_ACTION, LOG_INFO, "deleted ftp-account '" . $result['username'] . "'");
 				$db->query("UPDATE `" . TABLE_FTP_GROUPS . "` SET `members`=REPLACE(`members`,'," . $db->escape($result['username']) . "','') WHERE `customerid`='" . (int)$userinfo['customerid'] . "'");
@@ -273,6 +270,12 @@ elseif($page == 'accounts')
 
 				$sendinfomail = makeyesno('sendinfomail', '1', '0', '0');
 
+				$ftp_add_data = include_once dirname(__FILE__).'/lib/formfields/customer/ftp/formfield.ftp_add.php';
+				$ftp_add_form = htmlform::genHTMLForm($ftp_add_data);
+
+				$title = $ftp_add_data['ftp_add']['title'];
+				$image = $ftp_add_data['ftp_add']['image'];
+
 				eval("echo \"" . getTemplate("ftp/accounts_add") . "\";");
 			}
 		}
@@ -355,7 +358,13 @@ elseif($page == 'accounts')
 						$domains.= makeoption($idna_convert->decode($row_domain['domain']), $row_domain['domain']);
 					}
 				}
-				
+
+				$ftp_edit_data = include_once dirname(__FILE__).'/lib/formfields/customer/ftp/formfield.ftp_edit.php';
+				$ftp_edit_form = htmlform::genHTMLForm($ftp_edit_data);
+
+				$title = $ftp_edit_data['ftp_edit']['title'];
+				$image = $ftp_edit_data['ftp_edit']['image'];
+
 				eval("echo \"" . getTemplate("ftp/accounts_edit") . "\";");
 			}
 		}
