@@ -150,6 +150,11 @@ class db
 		return @mysql_close($this->link_id);
 	}
 
+	function getDbName()
+	{
+		return $this->database;
+	}
+
 	/**
 	 * Escapes user input to be used in mysql queries
 	 *
@@ -181,23 +186,37 @@ class db
 	 * @return string RessourceId
 	 */
 
-	function query($query_str, $unbuffered = false)
+	function query($query_str, $unbuffered = false, $suppress_error = false)
 	{
 		global $numbqueries;
 
 		if(!$unbuffered)
 		{
-			$this->query_id = mysql_query($query_str, $this->link_id);
+			if($suppress_error)
+			{
+				$this->query_id = @mysql_query($query_str, $this->link_id);
+			} else {
+				$this->query_id = mysql_query($query_str, $this->link_id);
+			}
 		}
 		else
 		{
-			$this->query_id = mysql_unbuffered_query($query_str, $this->link_id);
+			if($suppress_error)
+			{
+				$this->query_id = @mysql_unbuffered_query($query_str, $this->link_id);
+			} else {
+				$this->query_id = mysql_unbuffered_query($query_str, $this->link_id);
+			}
 		}
 
-		if(!$this->query_id)
+		if(!$this->query_id && !$suppress_error)
 		{
 			$this->showerror('Invalid SQL: ' . $query_str);
 		}
+		elseif(!$this->query_id && $suppress_error)
+		{
+			return false;
+		}
 
 		$numbqueries++;
 
