@@ -27,6 +27,7 @@ class htmlform
 	public static function genHTMLForm($data = array())
 	{
 		global $lng;
+		$nob = false;
 
 		self::$_form = '';
 
@@ -47,7 +48,11 @@ class htmlform
 					continue;
 				}
 	
-				eval("self::\$_form .= \"" . getTemplate("misc/form/table_section", "1") . "\";");
+				if (!isset($section['nobuttons']) || $section['nobuttons'] == false) {
+					eval("self::\$_form .= \"" . getTemplate("misc/form/table_section", "1") . "\";");
+				} else {
+					$nob = true;
+				}
 
 				$nexto = false;
 				foreach($section['fields'] as $fieldname => $fielddata)
@@ -63,7 +68,7 @@ class htmlform
 						$style = (isset($fielddata['style']) ? ' style="'.$fielddata['style'].'"' : '');
 						$mandatory = self::_getMandatoryFlag($fielddata);
 						$data_field = self::_parseDataField($fieldname, $fielddata);
-						$data_field = str_replace("\n", "", $data_field);
+						//$data_field = str_replace("\n", "", $data_field);
 						$data_field = str_replace("\t", "", $data_field);
 						if (isset($fielddata['has_nextto'])) {
 							$nexto = array('field' => $fieldname);
@@ -74,7 +79,7 @@ class htmlform
 						eval("self::\$_form .= \"" . getTemplate("misc/form/table_row", "1") . "\";");
 					} else {
 						$data_field = self::_parseDataField($fieldname, $fielddata);
-						$data_field = str_replace("\n", "", $data_field);
+						//$data_field = str_replace("\n", "", $data_field);
 						$data_field = str_replace("\t", "", $data_field);
 						$data_field = $fielddata['next_to_prefix'].$data_field;
 						self::$_form = str_replace(
@@ -87,7 +92,12 @@ class htmlform
 				}
 			}
 		}
-		
+
+		// add save/reset buttons at the end of the form
+		if (!$nob) {
+			eval("self::\$_form .= \"" . getTemplate("misc/form/table_end", "1") . "\";");
+		}
+
 		return self::$_form;
 	}
 
