@@ -90,7 +90,7 @@ return Array(
 						),
 						'commands_2' => Array(
 							'pw groupadd vmail -g '.$settings['system']['vmail_gid'],
-							'pw useradd vmail -u '.$settings['system']['vmail_uid'].' -g '.$settings['system']['vmail_gid'].' -s/sbin/nologin -d/dev/null',			
+							'pw useradd vmail -u '.$settings['system']['vmail_uid'].' -g '.$settings['system']['vmail_gid'].' -s/sbin/nologin -d/dev/null',
 							'mkdir -p ' . $settings['system']['vmail_homedir'],
 							'chown -R vmail:vmail ' . $settings['system']['vmail_homedir'],
 							'chmod 0750 ' . $settings['system']['vmail_homedir']
@@ -136,10 +136,10 @@ return Array(
 							'etc_postfix_main.cf' => '/usr/local/etc/postfix/main.cf'
 						),
 						'commands_1' => Array(
-							'postmap /etc/postfix/mx_access'
+							'postmap /usr/local/etc/postfix/mx_access'
 						),
 						'restart' => Array(
-							'/etc/init.d/postfix restart'
+							'/usr/local/etc/rc.d/postfix restart'
 						)
 					),
 					'dkim' => Array(
@@ -220,14 +220,14 @@ return Array(
 				'label' => $lng['admin']['configfiles']['etc'],
 				'daemons' => Array(
 					'cron' => Array(
-                                                'label' => 'Crond (cronscript)',
+						'label' => 'Crond (cronscript)',
 						'commands' => Array(
-							'echo "*/1 * * * *     root     /usr/local/bin/php -q /var/customers/froxlor/scripts/froxlor_master_cronjob.php" >> /etc/crontab'
-							),
-                                                'restart' => Array(
-                                                        '/etc/rc.d/cron restart'
-                                                )
-                                        ),
+							'echo "*/5 * * * *     root     /usr/local/bin/php -q '.makeCorrectDir(dirname(dirname(dirname(__FILE__)))).'scripts/froxlor_master_cronjob.php" >> /etc/crontab'
+						),
+						'restart' => Array(
+							'/etc/rc.d/cron restart'
+						)
+					),
 					'awstats' => Array(
 						'label' => 'Awstats',
 						'commands' => Array(
@@ -267,5 +267,3 @@ return Array(
 		)
 	)
 );
-
-?>
