@@ -172,7 +172,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['email_quota'],
 						'maxlength' => 9,
-						'visible' => $settings['system']['mail_quota_enabled'],
+						'visible' => ($settings['system']['mail_quota_enabled'] == '1' ? true : false),
 						'mandatory' => true,
 						'ul_field' => $email_quota_ul
 					),
@@ -181,7 +181,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['email_autoresponder'],
 						'maxlength' => 9,
-						'visible' => $settings['autoresponder']['autoresponder_active'],
+						'visible' => ($settings['autoresponder']['autoresponder_active'] == '1' ? true : false),
 						'ul_field' => $email_autoresponder_ul
 					),
 					'email_imap' => array(
@@ -208,7 +208,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['tickets'],
 						'maxlength' => 9,
-						'visible' => $settings['ticket']['enabled'],
+						'visible' => ($settings['ticket']['enabled'] == '1' ? true : false),
 						'ul_field' => $tickets_ul
 					),
 					'mysqls' => array(
@@ -234,7 +234,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['aps_packages'],
 						'maxlength' => 9,
-						'visible' => $settings['aps']['aps_active'],
+						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false),
 						'ul_field' => $number_of_aps_packages_ul
 					)
 				)
