@@ -28,17 +28,6 @@ return array(
 						'type' => 'label',
 						'value' => $result['username'],
 					),
-					'ftp_username' => array(
-						'visible' => ($settings['customer']['ftpatdomain'] == '1' ? true : false),
-                                                'label' => $lng['login']['username'],
-                                                'type' => 'text'
-                                        ),
-					'ftp_domain' => array(
-						'visible' => ($settings['customer']['ftpatdomain'] == '1' ? true : false),
-						'label' => $lng['domains']['domainname'],
-						'type' => 'select',
-						'select_var' => (isset($domains) ? $domains : ""),
-					),
 					'path' => array(
 						'label' => $lng['panel']['path'],
 						'desc' => ($settings['panel']['pathedit'] != 'Dropdown' ? $lng['panel']['pathDescription'] : null).(isset($pathSelect['note']) ? '<br />'.$pathSelect['value'] : ''),
