@@ -17,7 +17,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_autoresponder.php 1452 2010-11-11 09:23:53Z d00p $
+ * @version    $Id$
  * @todo	   skip mail parsing after x bytes for large mails
  */
 
@@ -201,7 +201,7 @@ if($db->num_rows($result) > 0)
 				//error while parsing mail
 				if($to == '' || $from == '')
 				{
-					$cronlog->logAction(CRON_ACTION, LOG_WARNING, "No valid headers found in mail to parse: " . $entry);
+					$cronlog->logAction(CRON_ACTION, LOG_WARNING, "No valid headers found in mail to parse");
 					continue;
 				}
 
